__version__ = "3.0.1"
__all__ = ["while_true_print_howdyho_help"]


def while_true_print_howdyho_help():
    while True:
        print("Хаудихо помоги")
